@@ -13,11 +13,10 @@ LK <- function(data, fixed=c(FALSE,FALSE,FALSE,FALSE,FALSE)){
   #Initialize parameters values
   alpha <- params[1];  #alpha 
   delta  <- params[2]; #delta
-  mu <- params[3];     #mu
-  epsb <- params[4];   #epsilon_b
-  epss <- params[5];   #epsilon_s
+  mu <- params[3]; #mu
+  epsb <- params[4]; #e_b
+  epss <- params[5]; #e_s
   
-  # From now on LK stands for likelihood function.
   #Initialize
   LK_I <- c(0);
   
@@ -33,7 +32,7 @@ LK <- function(data, fixed=c(FALSE,FALSE,FALSE,FALSE,FALSE)){
     
     #Split the log-likelihood in two parts and compute the relevant terms
     part1<- -epsb-epss+buy_s*log(mu+epsb)+sell_s*log(mu+epss)+emax
-    part2<- log(alpha*(1-delta)*exp(e1-emax)+alpha*delta*exp(e2-emax)+(1-alpha)*exp(e3-emax))
+    part2<- log(alpha*delta*exp(e1-emax)+alpha*(1-delta)*exp(e2-emax)+(1-alpha)*exp(e3-emax))
     
     LK_I <- LK_I + (part1+part2)
   
